# sspo_db

Acesso ao SSPO's Database

## Migration
Steps:
## Create Migration File: 
 
 ```bash
 alembic init --template generic alembic
 ```

## Migrations


## Reference
https://michaelheap.com/alembic-python-migrations-quick-start/
https://www.compose.com/articles/schema-migrations-with-alembic-python-and-postgresql/

https://woile.github.io/commitizen/
https://woile.github.io/commitizen/tutorials/gitlab_ci/

#Changelog
gitchangelog > CHANGELOG.md 

sgajgsasjagsjajsjagsjga